/*
 *      scr.c from Access Point SNMP Utils for Linux
 *	program screen operate functions
 *
 * Copyright (c) 2002 Roman Festchook <roma at polesye dot net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2 from
 * June 1991 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
#include <stdlib.h>
#include <ncurses.h>
#include <menu.h>
#include <string.h>
#include "ap-utils.h"

extern WINDOW *main_sub, *win_for_help, *main_win;

void
scroll_rows(struct MacListStat *first, int begin, int end, int row,
	    int stat)
{
    int i = 1;
    struct MacListStat *curr = first;
    char message[50];

    clear_main(3);

    while (i++ < begin)
	curr = curr->next;
    i = 0;
    while (end-- > begin) {
	if (stat)
	    sprintf(message,
		    "%5u       %02X%02X%02X%02X%02X%02X     %3u%5u   %3u",
		    begin + i, curr->addr[0] & 0xFF, curr->addr[1] & 0xFF,
		    curr->addr[2] & 0xFF, curr->addr[3] & 0xFF,
		    curr->addr[4] & 0xFF, curr->addr[5] & 0xFF,
		    curr->quality, curr->idle, curr->rssi);
	else
	    sprintf(message, "%5u       %02X%02X%02X%02X%02X%02X",
		    begin + i, curr->addr[0] & 0xFF, curr->addr[1] & 0xFF,
		    curr->addr[2] & 0xFF, curr->addr[3] & 0xFF,
		    curr->addr[4] & 0xFF, curr->addr[5] & 0xFF);
	mvwaddstr(main_sub, row + i, 3, message);
	i++;
	curr = curr->next;
    }
    wrefresh(main_sub);

}

int get_value(char *value, int line, int column, int len)
{
    int i;

    echo();
    wattrset(main_sub, COLOR_PAIR(2));
    mvwaddch(main_sub, line, column, ' ');
    for (i = 0; i < len - 2; i++)
	waddch(main_sub, ' ');
    curs_set(1);
    mvwgetnstr(main_sub, line, column, value, len - 1);
    curs_set(0);
    noecho();
    value[len - 1] = '\0';
    wattrset(main_sub, A_NORMAL);
    return 0;
}

void print_help(char *mess)
{
    int j;

    werase(win_for_help);

    for (j = 0; j < COLS; j++)
	waddch(win_for_help, ' ');

    mvwaddstr(win_for_help, 0, (COLS - strlen(mess)) / 2, mess);
    wrefresh(win_for_help);
}

void print_title(char *mess)
{
    int i;
    /*   */
    for (i = 0; i < COLS - MCOLS - 1; i++)
	mvwaddch(main_win, 0, i, ACS_BSBS);
    wattrset(main_win, A_BOLD);
    mvwaddstr(main_win, 0, COLS - MCOLS - strlen(mess) - 1, mess);
    wattrset(main_win, A_NORMAL);
    wrefresh(main_win);
}

void print_bottom(char *mess)
{
    int i;
    char message[100];
    extern short ap_type;

    sprintf(message, _("Current AP: %s Type: %s"), mess, (ap_type ==0) ? "atmel" : "nwn");
    /*   */
    for (i = 0; i < COLS - MCOLS - 1; i++)
	mvwaddch(main_win, LINES - 3, i, ACS_BSBS);
    wattrset(main_win, A_BOLD);
    mvwaddstr(main_win, LINES - 3, COLS - MCOLS - strlen(message) - 1,
	      message);
    wattrset(main_win, A_NORMAL);
    wrefresh(main_win);
}


void clear_main(int m)
{
    clear_main_new(m, LINES - 4);
}

void clear_main_new(int m, int n)
{
    int i, j;
    wmove(main_sub, m, 0);
    for (i = m; i < n; i++)
	for (j = 0; j < COLS - MCOLS - 1; j++)
	    waddch(main_sub, ' ');
    wrefresh(main_sub);
}

int on_off(int bcol, int brow)
{
    char *names[2] = { ON, OFF };
    return menu_choose(bcol, brow, names, 2) + 1;
}


int menu_choose(int bcol, int brow, char **names, unsigned int num)
{
    unsigned short int c;
    ITEM **menu_item = calloc(num, sizeof(ITEM)), **ip = menu_item;
    MENU *menu1;
    unsigned int ncol = 2, i, nrow;
    WINDOW *choose_menu, *sub_choose_menu;
    extern WINDOW *main_sub;

    for (i = 0; i < num; i++) {
	*ip++ = new_item(names[i], "");
	if (ncol < strlen(names[i]) + 3)
	    ncol = strlen(names[i]) + 3;
    }
    *ip = (ITEM *) 0;


    nrow = num + 2;
    if (brow + 2 + nrow <= (unsigned int) LINES - 2)
	choose_menu = newwin(nrow, ncol, brow + 2, bcol + MCOLS);
    else
	choose_menu = newwin(nrow, ncol, brow - nrow + 3, bcol + MCOLS);
    sub_choose_menu = derwin(choose_menu, nrow - 2, ncol - 2, 1, 1);
    attrset(COLOR_PAIR(1));

    mvwaddch(choose_menu, 0, 0, ACS_ULCORNER);
    mvwaddch(choose_menu, 0, ncol - 1, ACS_URCORNER);
    mvwaddch(choose_menu, nrow - 1, 0, ACS_LLCORNER);
    mvwaddch(choose_menu, nrow - 1, ncol - 1, ACS_LRCORNER);
    for (i = 1; i < ncol - 1; i++) {
	mvwaddch(choose_menu, 0, i, ACS_HLINE);
	mvwaddch(choose_menu, nrow - 1, i, ACS_HLINE);
    }
    for (i = 1; i < nrow - 1; i++) {
	mvwaddch(choose_menu, i, 0, ACS_VLINE);
	mvwaddch(choose_menu, i, ncol - 1, ACS_VLINE);
    }
    wrefresh(choose_menu);


    menu1 = new_menu(menu_item);
    set_menu_win(menu1, choose_menu);
    set_menu_sub(menu1, sub_choose_menu);

    set_menu_opts(menu1, O_ONEVALUE);

    curs_set(0);
    post_menu(menu1);
    wrefresh(sub_choose_menu);

    while (1) {
	switch (getch()) {
	case KEY_DOWN:
	    menu_driver(menu1, REQ_NEXT_ITEM);
	    wrefresh(sub_choose_menu);
	    break;
	case KEY_RIGHT:
	    menu_driver(menu1, REQ_LAST_ITEM);
	    wrefresh(sub_choose_menu);
	    break;
	case KEY_LEFT:
	    menu_driver(menu1, REQ_FIRST_ITEM);
	    wrefresh(sub_choose_menu);
	    break;
	case KEY_UP:
	    menu_driver(menu1, REQ_PREV_ITEM);
	    wrefresh(sub_choose_menu);
	    break;
	case 10:
	    i = item_index(current_item(menu1));
	    unpost_menu(menu1);
	    free_menu(menu1);
	    for (c = 0; c < nrow - 2; c++)
		free_item(menu_item[c]);
	    delwin(sub_choose_menu);
	    delwin(choose_menu);
	    redrawwin(main_sub);
	    free(menu_item);
	    return i;

	}
    }
}
